function [x,w,p]=GaussGeg(n,lam)
% GEGENBAUER POLYNOMIALS: zeroes and gaussian integration coefficients. 
% Usage:  [x,w,p]=gaussgeg(n,[a])
% returns p=C_j(x_k), j,k=0:n-1
%  	  x=zeros of C_{n}
%	  w= Gauss integration weights
% Computes \int_{-1}^{1} (1-x^2)^(lam-1/2) f(x) dx ~ \sum(w.*f(x))
% Es. \int((1-x^2)^(1/2) cos(x) dx = pi*J1(1) ~ 1.382459687384169
% With n=5: 1.38245968779896 (relative error 3x10^-10)
%      n=10:  (relative error 3x10^-16)
% Limitations: lam must be greater than -1/2.
% Bugs: n>100 may give inaccurate results or NaNs because of
%   gamma(n+...);
% See Golub and Welsch, Math.Comput. 23 (1969) 221-230


if nargin<2,
  disp('Applying default parameters lam=1/2');
  lam=.5;
end

disp('Gegenbauer polynomials are a special case of Jacobi');
[x,w,p]=GaussJac(n,lam-.5,lam-.5);
