function [x,w,p]=gausherm(n)
% HERMITE POLYNOMIALS: zeroes and gaussian integration coefficients. 
% Usage:
%	[x,w,p]=gausherm(n)
%
% 	returns p=H_j(x_k), j,k=0:n-1 (orthonormal)
%       	x roots of H_{n}
%	  	w Gauss integration weights for the measure
%	  	\int exp(-x^2) dx/sqrt(pi)
%
%   Ex. sum(w.*x.^10)= 10!/2^5/5! * (1/2)^5 = 29.53125999999 = 945/32
%   Ex. sum(w.*exp(2*i*x) = .36787944117144 = exp(-1)
%
disp('Building the companion matrix of H_n(x)');
disp(' ');

l1=sqrt(1:n-1)/sqrt(2);

D=diag(l1,-1)+diag(l1,1);

disp('            ... and diagonalizing it:');
disp(' ');

[U,X]=eig(D);
[x,ind]=sort(-diag(X)');

U=U(:,ind);

disp('Build Hermite polynomials and Gauss weights');
disp(' ');

p0=U;
w=p0(1,:).^2;
p=U/diag(p0(1,:));

