function [x,w,p]=gauslag(n,a,b)
% LAGUERRE POLYNOMIALS: zeroes and gaussian integration coefficients. 
% Usage:  [x,w,p]=gausslag(n,a)
% default a=0 
%
% returns p=L_j(x_k), j,k=0:n-1
%  	  x=zeros of L_{n}
%	  w= Gauss integration weights
%
% Computes \int_0^{\inf} x^a exp{-x} f(x) dx ~ \sum(w.*f(x))
% See Golub and Welsch, Math.Comput. 23 (1969) 221-230
%%%%


if nargin<2,
  disp('Applying default parameters a=0');
  a=0;
end

if(a<=-1)
  error('wrong range of parameters a <-1');
end
  
disp('Building the companion matrix of Laguerre L_n(x)');
disp(' ');

N=0:n-1;

D1=sqrt((a+N+1).*(N+1));
D0=-(2*N+a+1);

D=diag(D1(1:n-1),1)+diag(D1(1:n-1),-1)+diag(D0);

disp('   ... and diagonalizing it:');
disp(' ');

[A,B]=eig(D);
[x,ind]=sort(-diag(B)');

A=A(:,ind);

disp('Build Laguerre polynomials and Gauss weights');
disp(' ');

H=gamma(a+1);

p0=A;
w=p0(1,:).^2*H;
p=A/diag(p0(1,:));

disp('Gauss quad rule: int(f(x) exp(-x) dx) ~ sum(w.*f(x))');
