function [x,w,p]=GaussLeg(n)
% Legendre polynomials: zeroes and gaussian integration coefficients. 
% Usage:  [x,w,p]=gaussleg(n)
% returns p = P_j(x_k), j,k=0:n-1
%  	  x = zeros of P_{n}
%	  w = Gauss integration weights
% Computes \int_{-1}^{1} f(x) dx ~ \sum(w.*f(x))
% See Golub and Welsch, Math.Comput. 23 (1969) 221-230

disp('Building the companion matrix of Legendre P_n(x)');
disp(' ');

N=0:n-1;

K=2.^N ./beta(1/2,N+1)./(N+1/2);
Kp=2.^(N+1) ./beta(1/2,N+2)./(N+3/2);

H=1./(N+1/2);
    
Hp=1./(N+3/2);
   
D1=K./Kp.*sqrt(Hp./H);

D=diag(D1(1:n-1),1)+diag(D1(1:n-1),-1);

disp('  ... and diagonalizing it:');
disp(' ');

[A,B]=eig(D);
[x,ind]=sort(-diag(B)');

A=A(:,ind);

disp('Build Legendre polynomials and Gauss weights');
disp(' ');

p0=A;
w=p0(1,:).^2*H(1);
p=A/diag(p0(1,:));

disp('Gauss quad rule: int(f(x) dx) ~ sum(w.*f(x))');
