function q = gaussq(f,n,opt)
% Driver program for Gaussian integration over 
% classical polynomials
% Usage:
%     gausq('func',Npts [, options])
%    where
% 'func' is the name of the function to integrate; it can be 
%    a built-in function or the name of a M-file
% Npts is the number of Gaussian points
% At the prompt you may choose one of the classical polynomials
% which define the Gauss quadrature rule.
% Try: help gaussleg, gausslag, gaussherm, gaussgeg, gaussjac
%%%


if(nargin<2),
    error('Please provide the number of nodes');
    exit
end
selection = {'jacobi','hermite','gegenbauer','legendre','laguerre'};
choice    = menu('Quad rule',selection);

switch choice
 case 1				
  if nargin == 2,
    [x,w]=gaussjac(n);
  elseif length(opt)==2,
    [x,w]=gaussjac(n,opt(1),opt(2));
  else,
    [x,w]=gaussjac(n,opt(1));
  end
 case 2
  [x,w]=gaussher(n);
 case 3
  if nargin==2,
    [x,w]=gaussgeg(n);
  else,
    [x,w]=gaussgeg(n,opt(1));      
  end
 case 4
  [x,w]=gaussleg(n);
 case 5
  if nargin==2,
    [x,w]=gausslag(n);
  else,
    [x,w]=gausslag(n,opt(1));
  end
  
 otherwise
  error('illegal option');
end

F=feval(f,x);

q=sum(w.*F);
