function q = Gaussquad(f,n,meas,opt)
% Driver program for Gaussian integration over 
% classical polynomials
% Usage:
%         gausquad('func',Npts,'type',[options])
% where
% 'func' is the name of the function to integrate
% Npts = number of Gaussian points
% 'type'= one of 'her' (Hermite)
%                'leg' (Legendre)
%                'lag' (Laguerre) (opt=a for the measure x^a e^(-x))
%                'jac' (Jacobi)   (opt=[a,b]  "    "  (1-x)^a (1+x)^b
%                'geg' (Gegenbauer) (opt=l for the measure (1-x^2)^(l-1/2)
%                'che' (Chebyshev) to do......
% Try help gaussleg, gausslag, gaussherm, gaussgeg, gaussjac
%%%

if(meas=='jac'),
  if nargin == 3,
    [x,w]=GaussJac(n);
  elseif length(opt)==2,
    [x,w]=GaussJac(n,opt(1),opt(2));
  else,
    [x,w]=GaussJac(n,opt(1));
  end
elseif (meas=='her'),
  [x,w]=GaussHer(n);
elseif (meas=='geg'),
  if nargin==3,
    [x,w]=GaussGeg(n);
  else,
    [x,w]=GaussGeg(n,opt(1));      
  end
elseif (meas=='leg'),
  [x,w]=GaussLeg(n);
elseif (meas=='lag'),
  if nargin==3,
    [x,w]=GaussLag(n);
  else,
    [x,w]=GaussLag(n,opt(1));
  end
end

if(exist('x')==0)
    error(['type unrecongnized: ', meas])
else
    F=feval(f,x);
    
    q=sum(w.*F);
end
